# remove repeating letters
import re
def remove_recurring_letters(sentence):
    words = sentence.split()
    modified_sentence = []
    for word in words:
        modified_word = re.sub(r"(.)\1+", r"\1", word)
        modified_sentence.append(modified_word)
    return ' '.join(modified_sentence)




import re
import os
import pickle
from sklearn.feature_extraction.text import CountVectorizer
from .util import remove_recurring_letters

def censor_text(sentence):
    # Load the machine learning model
    model_path = os.path.join(os.path.dirname(__file__), 'models', 'rf_model.pkl')
    with open(model_path, 'rb') as f:
        model = pickle.load(f)
    # Load the vocabulary used for training
    vocabulary_path = os.path.join(os.path.dirname(__file__), 'models', 'vocabulary.pkl')
    with open(vocabulary_path, 'rb') as f:
        vocabulary = pickle.load(f)
    # Extract features
    vectorizer = CountVectorizer(vocabulary=vocabulary)
    # preprocessing sentences
    sentence = remove_recurring_letters(sentence)
    # Split sentence into individual words
    sentence_tokens = sentence.split()
    censored_tokens = []
    
    for token in sentence_tokens:
        #lowercase
        preprocessed_token = token.lower()  # Perform any necessary preprocessing steps
        token_features = vectorizer.transform([preprocessed_token])
        # Predict the class
        if model.predict(token_features)[0] ==1:
            censored_tokens.append('*'*len(token))  # Replace profane word with censor symbol
        else:
            censored_tokens.append(token)  # Keep non-profane word as is
    
    censored_text = ' '.join(censored_tokens)  # Join censored tokens into a sentence
    return censored_text




from setuptools import setup
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='censoredzz',
    version='1.0.6',
    description='Python package for censoring profane words in Nepali-(Roman) text',
    author='Kuber Budhathoki',
    author_email='koobear99@gmail.com',
    url='https://github.com/12-Twelvve/pypi_censored_text',
    packages=['censoredzz'],
    package_data={
        'censoredzz': ['models/rf_model.pkl', 'models/vocabulary.pkl'],
    },
    install_requires=[
        'regex',
        'scikit-learn',
    ],
    long_description=long_description,
    long_description_content_type='text/markdown',
) 